BrillouinZone
========================

The :class:`pyprocar.core.BrillouinZone` is used to generates the Brillouin Zone from reciprocal lattice matrix. 

.. autosummary::
   :toctree: _autosummary

   pyprocar.core.BrillouinZone